**************************
  What's New In Pylint 1.6
**************************

.. include:: ../../full_changelog_explanation.rst
.. include:: ../../summary_explanation.rst

Ticket numbers can be internal to logilab or come from bitbucket.

.. toctree::
   :maxdepth: 2

   summary.rst
   full.rst
